<p align="center">
	👉 <a target="_blank" href="https://www.python-office.com/">项目官网：https://www.python-office.com/</a> 👈
</p>
<p align="center">
	👉 <a target="_blank" href="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg">本开源项目的交流群</a> 👈
</p>



-------------------------------------------------------------------------------

## 📚简介

poword 是python自动化办公之Word操作的第三方库。

来自于开源项目：python-office，[📘官网：https://www.python-office.com/](https://www.python-office.com/)。

-------------------------------------------------------------------------------

## 📦安装

### 🍊pip 自动下载&更新

```
pip install -i https://mirrors.aliyun.com/pypi/simple/ poword -U
```

-------------------------------------------------------------------------------

## 📝功能

已有功能的说明如下：



 | 序号 | 方法名            | 功能                | 视频                                                | 文档                                                      | 演示代码                                                                                                            |
 | ---- | ----------------- | ------------------- | --------------------------------------------------- | --------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------- |
 | 1    | merge4docx        | 合并Word文档        | [播放](https://www.bilibili.com/video/BV1Vo4y1q7i3) | [查看](https://mp.weixin.qq.com/s/PjQJ3s4Arr872NDfcr-7YA) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/poword/%E5%90%88%E5%B9%B6word.py)             |
 | 2    | docx2doc/doc2docx | doc和docx，互相转换 | [播放](https://www.bilibili.com/video/BV1so4y1H7rj) | [查看](https://mp.weixin.qq.com/s/nyg_LlkHPwx1AY7wCg5KTw) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/poword/doc%E5%92%8Cdocx%E4%BA%92%E8%BD%AC.py) |
 | 3    | docx2pdf          | word 转 pdf         | [播放](https://www.bilibili.com/video/BV1pT4y1k7FH) | [查看](https://mp.weixin.qq.com/s/Kfmu8vCSr6otGfrf7mj0bA) | [打开](https://github.com/CoderWanFeng/python-office/blob/master/demo/poword/word%E8%BD%ACPDF.py)                   |

## 🏗️添砖加瓦

本项目欢迎任何人参与开发，如果是小白，可以看一下开发教程👉[如何参与开源项目？0基础入门：怎么打开GitHub？什么是issue？什么是PR？](https://www.bilibili.com/video/BV1EP411d7Np/?spm_id_from=333.999.0.0)

### 🐞提供bug反馈或建议

提交问题反馈时，请务必填写和该项目本身有关的问题，不进行有关python学习，甚至是个人练习的知识答疑和讨论。

- [Github issue](https://github.com/CoderWanFeng/poword/issues)
- [gitee issue](https://gitee.com/CoderWanFeng/poword/issues)
### 🧬贡献代码的步骤

1. 在Gitee或者Github上fork项目到自己的repo
2. 把fork过去的项目也就是你的项目clone到你的本地
3. 修改代码
4. commit后push到自己的库
5. 登录Gitee或Github在你首页可以看到一个 pull request 按钮，点击它，填写一些说明信息，然后提交到master分支即可。
6. 等待程序员晚枫合并，＋微信说一声更好👉[CoderWanFeng](http://python4office.cn/wechat-qrcode/)

-------------------------------------------------------------------------------

## 📌联系作者

<p align="center" id='开源交流群-banner'>
<a target="_blank" href='https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office.jpg'>
<img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/python-office-qr.jpg" width="100%"/>
</a> 
</p>

## 读者福利

几个没有套路的福利，每天都可以领一次~

<p align="center" id='福利合集-banner'>
    <a target="_blank" href='http://python4office.cn/sideline-pro-list/'>
    <img src="https://python-office-1300615378.cos.ap-chongqing.myqcloud.com/fuli.jpg" width="100%"/>
    </a>   
</p>